@@ -78,10 +78,10 @@ print_dust_latex_hhline <- function(x, ..., asis=TRUE)
   if (tab_env == "longtable")
   {
     begin <- paste0("\\begin{longtable}[",
-                    substr(x[["justify"]], 1, 1), "]{",
+                    sub("n", "l", substr(x[["justify"]], 1, 1)), "]{",
                     paste0(col_halign_default$default_halign, collapse = ""), "}\n",
                     if (!is.null(x$caption))
-                      paste("\\caption{", x$caption, "}\\\\")
+                      paste("\\caption{", x$caption, "}")
                     else "", 
                     "\n", label, "\\\\ \n")
     end <- "\\end{longtable}"
@@ -374,4 +374,4 @@ utils::globalVariables(c("halign", "left_border", "right_border",
                          "require_multicol", "height", "width",
                          "height_units", "width_units", "table_width",
                          "parbox", "width_by_char", "html_row", 
-                         "html_col", "rowspan", "colspan", "group"))
\ No newline at end of file
+                         "html_col", "rowspan", "colspan", "group"))
